@@ -44,12 +44,14 @@ pkg_download <- function(avail_pkgs, dest_dir) {
 
     build_result <- run_rscript(c("load(%s)",
                                   "remote_paths <- matrix(character(), 0L, 2L)",
-                                  paste0("for (p in pkgs$Package) ",
+                                  paste0("for (pIx in seq_len(nrow(pkgs))) {",
+                                         "prow <- pkgs[pIx,];",
                                          "tryCatch({",
-                                         "res <- download.packages(p, available = pkgs, %s); ",
+                                         "res <- download.packages(prow$Package, available = prow, %s); ",
                                          "remote_paths <- rbind(remote_paths, res)}, ",
                                          "warning = function(w) {}, ",
-                                         "error = function(e) {})"),
+                                         "error = function(e) {})",
+                                         "}"),
                                   "save(remote_paths, %s)"),
                                 rscript_arg("file", in_file),
                                 paste(common_args, collapse = ", "),
